"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OtpResponseBodyTypedDict(TypedDict):
    r"""Success"""

    otp: NotRequired[str]
    r"""The one time password"""


class OtpResponseBody(BaseModel):
    r"""Success"""

    otp: Optional[str] = ""
    r"""The one time password"""
