"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ScoreRequestBodyTypedDict(TypedDict):
    r"""The request object.  Must include the question and a context."""

    text: NotRequired[str]
    r"""The text to score"""
    passages: NotRequired[List[str]]
    r"""The rating score. An integer, 0-5. 0 is worst, 5 is best.  For Thumbs up / Thumbs down send 0 or 5"""


class ScoreRequestBody(BaseModel):
    r"""The request object.  Must include the question and a context."""

    text: Optional[str] = ""
    r"""The text to score"""

    passages: Optional[List[str]] = None
    r"""The rating score. An integer, 0-5. 0 is worst, 5 is best.  For Thumbs up / Thumbs down send 0 or 5"""
