"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AnalyticsRequestBodyTypedDict(TypedDict):
    r"""The request object.  You may optionally limit the result set using \"count\" """

    count: NotRequired[int]
    r"""The number of rows to return"""


class AnalyticsRequestBody(BaseModel):
    r"""The request object.  You may optionally limit the result set using \"count\" """

    count: Optional[int] = None
    r"""The number of rows to return"""
