"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TrainRequestBodyTypedDict(TypedDict):
    r"""The request object.  Must include the question and a context."""

    train: NotRequired[str]
    r"""The training token. Get this from passages/train"""
    score: NotRequired[int]
    r"""The relevancy score. An integer, 0-100"""


class TrainRequestBody(BaseModel):
    r"""The request object.  Must include the question and a context."""

    train: Optional[str] = ""
    r"""The training token. Get this from passages/train"""

    score: Optional[int] = None
    r"""The relevancy score. An integer, 0-100"""
