"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class PiiRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    text: NotRequired[str]
    r"""The user utterance to check for PII"""


class PiiRequestBody(BaseModel):
    r"""The request object."""

    text: Optional[str] = ""
    r"""The user utterance to check for PII"""


class PiiResponseBodyTypedDict(TypedDict):
    pii: NotRequired[List[str]]
    r"""An array of found PII"""


class PiiResponseBody(BaseModel):
    pii: Optional[List[str]] = None
    r"""An array of found PII"""
