"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
import pydantic
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class RateRequestBodyTypedDict(TypedDict):
    r"""The request object."""

    answer_id: NotRequired[int]
    r"""The answer id"""
    score: NotRequired[int]
    r"""The rating score. An integer, 0-5. 0 is worst, 5 is best.  For Thumbs up / Thumbs down send 0 or 5"""


class RateRequestBody(BaseModel):
    r"""The request object."""

    answer_id: Annotated[Optional[int], pydantic.Field(alias="answerId")] = None
    r"""The answer id"""

    score: Optional[int] = None
    r"""The rating score. An integer, 0-5. 0 is worst, 5 is best.  For Thumbs up / Thumbs down send 0 or 5"""
