"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from neuralseek.types import BaseModel
from neuralseek.utils import FieldMetadata, QueryParamMetadata
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteUserDataRequestTypedDict(TypedDict):
    intent: NotRequired[List[str]]
    r"""The intents to delete. If left blank all intents will be deleted."""


class DeleteUserDataRequest(BaseModel):
    intent: Annotated[
        Optional[List[str]],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""The intents to delete. If left blank all intents will be deleted."""
